from nltk import FreqDist, word_tokenize, pos_tag
from nltk.corpus import wordnet
from nltk.stem import WordNetLemmatizer
from nltk.tokenize import MWETokenizer


# Helper function to convert PTB tags to WordNet tags
def get_wordnet_pos(PTB_tag):
    if PTB_tag.startswith('J'):
        return wordnet.ADJ
    elif PTB_tag.startswith('V'):
        return wordnet.VERB
    elif PTB_tag.startswith('N'):
        return wordnet.NOUN
    elif PTB_tag.startswith('R'):
        return wordnet.ADV
    else:  # indeclinable word
        return None


mwe_list = [('palm', 'frond'), ('coast', 'guard')]
mwe = MWETokenizer(mwe_list, separator='_')
my_lemmatizer = WordNetLemmatizer()

print("\nFrequency distribution after lemmatization and mwe resolution:\n" + "=" * 60)


tokens = word_tokenize("The Coast Guard saw palm fronds on the island. Every palm frond was used to spell SOS.")
tagged = pos_tag(tokens)

lemmas = []
for token, tag in tagged:
    wordnet_tag = get_wordnet_pos(tag)
    if wordnet_tag is not None:
        lemmas.append(my_lemmatizer.lemmatize(token.lower(), wordnet_tag))
    else:
        lemmas.append(token.lower())

mwe_tokenized = mwe.tokenize(lemmas)

processed_freqs = FreqDist(mwe_tokenized)

for term, freq in processed_freqs.most_common(10):
    print(term + "\t" + str(freq))

